use crate::physics::PhysVec;
use std::f64::consts::{PI, TAU};

pub struct PhysBody {
	pub pos: PhysVec,
	pub vel: PhysVec,
	pub mass: f64,
	pub angle: f64, // In radians
}

impl PhysBody {
	pub fn new() -> Self {
		return PhysBody {
			pos: PhysVec { x: 200.0, y: 200.0 },
			vel: PhysVec { x: 0.0, y: 0.0 },
			mass: 1.0,
			angle: 0.0,
		};
	}

	/// Calculate the state of this body after t seconds.
	pub fn tick(&mut self, t: f64) {
		self.pos += self.vel * t;
	}

	/// Apply an instantaneous force to this object
	pub fn force(&mut self, v: PhysVec) {
		self.vel += v / self.mass;
	}

	/// Apply force in the direction this object is pointing.
	pub fn thrust(&mut self, f: f64) {
		self.force(
			PhysVec {
				x: self.angle.sin(),
				y: -self.angle.cos(),
			} * f,
		);
	}

	// Rotate this object by `a` radians.
	pub fn rot(&mut self, a: f64) {
		self.angle -= a;
		if self.angle.abs() > PI {
			self.angle -= self.angle.signum() * TAU;
		}
	}
}
